@@ -25,8 +25,11 @@ chmod 755 ${LDAP_DATA}
 
 #ldifからデータを登録する。
 #エラーが出力された場合はログファイルを作成する。
-${LDAP}/sbin/slapadd -l ${HINEMOS_HOME}/sbin/db_init/hinemos_ldap.ldif 2> slapadd.log
-
+if [ $LANG = "C" ] ; then
+	${LDAP}/sbin/slapadd -l ${HINEMOS_HOME}/sbin/db_init/hinemos_ldap_en.ldif 2> slapadd.log
+else
+	${LDAP}/sbin/slapadd -l ${HINEMOS_HOME}/sbin/db_init/hinemos_ldap.ldif 2> slapadd.log
+fi
 #ログファイルに書き込まれている場合は失敗とみなす。
 if [ 0 -ne `cat slapadd.log  | wc -l` ] ; then
 	echo "Error occurred. Please check ./slapadd.log ";
