@@ -129,12 +129,12 @@ cp -pr $EXEC_PATH/hinemos /opt
 #インストールディレクトリに応じて各ファイルを変更
 REPLACE_PATH=`echo $HINEMOS_HOME | sed 's/\//\\\\\//g'`
 sed "s/%%hinemos_install_dir%%/$REPLACE_PATH/" $EXEC_PATH/hinemos.cfg > $HINEMOS_HOME/hinemos.cfg
-SCRIPTS=`ls $EXEC_PATH/bin`
-for CURSCRIPT in $SCRIPTS
-do
-	     sed "s/%%hinemos_install_dir%%/$REPLACE_PATH/" $EXEC_PATH/bin/$CURSCRIPT > $HINEMOS_HOME/bin/$CURSCRIPT
-	chmod 700 $HINEMOS_HOME/bin/$CURSCRIPT
-done
+#SCRIPTS=`ls $EXEC_PATH/bin`
+#for CURSCRIPT in $SCRIPTS
+#do
+#	     sed "s/%%hinemos_install_dir%%/$REPLACE_PATH/" $EXEC_PATH/bin/$CURSCRIPT > $HINEMOS_HOME/bin/$CURSCRIPT
+#	chmod 700 $HINEMOS_HOME/bin/$CURSCRIPT
+#done
 
 #ftpサーバのIPアドレス
 echo "Please input ftp server's IP address  for corrective run (default:127.0.0.1)"
@@ -144,8 +144,6 @@ sed "s/%%hinemos_ftp_host%%/$FTP_SERVER/"  $EXEC_PATH/hinemos/lib/cr/cp.sh > $HI
 sed "s/%%hinemos_ftp_host%%/$FTP_SERVER/"  $EXEC_PATH/hinemos/lib/cr/rpminstall.sh > $HINEMOS_HOME/lib/cr/rpminstall.sh
 sed "s/%%jre_version%%/$JRE_NAME/"  $EXEC_PATH/hinemos/lib/cr/agent_install.sh > $HINEMOS_HOME/lib/cr/agent_install.sh
 
-chown -R  $HINEMOS_USER:$HINEMOS_USER $HINEMOS_HOME
-
 echo "Copying required files was completed."
 echo ""
 
@@ -159,6 +157,12 @@ ${HINEMOS_HOME}/jre-1_5_0_09-linux-i586.bin
 rm ${HINEMOS_HOME}/jre-1_5_0_09-linux-i586.bin
 cd $CURRENT_DIR
 
+#ユーザを一般ユーザに変更する
+chown -R $HINEMOS_USER:$HINEMOS_USER $HINEMOS_HOME
+
+# fpingはrootユーザである必要があるため、再度コピーしなおす
+cp -pr $EXEC_PATH/hinemos/sbin/fping $HINEMOS_HOME/sbin/
+chmod 4755 $HINEMOS_HOME/sbin/fping
 
 #syslog-ngインストール
 echo "Start the installation of syslog-ng."
